Locking Script (scriptPubKey).
The LockingScript class represents a locking script in a Bitcoin SV transaction. It extends the Script class and is used specifically for output scripts that lock funds.
Structs
- Locking
Script - Represents a locking script (output script / scriptPubKey).