pub struct Spend { /* private fields */ }Expand description
The Spend struct represents a spend action and validates it by executing the unlocking and locking scripts.
Implementations
Sourceimpl Spend
impl Spend
Sourcepub fn new(params: SpendParams) -> Self
pub fn new(params: SpendParams) -> Self
Creates a new Spend validator from the given parameters.