SpendParams

Struct SpendParams 

pub struct SpendParams {
    pub source_txid: [u8; 32],
    pub source_output_index: u32,
    pub source_satoshis: u64,
    pub locking_script: LockingScript,
    pub transaction_version: i32,
    pub other_inputs: Vec<TxInput>,
    pub outputs: Vec<TxOutput>,
    pub input_index: usize,
    pub unlocking_script: UnlockingScript,
    pub input_sequence: u32,
    pub lock_time: u32,
    pub memory_limit: Option<usize>,
}
Parameters for constructing a Spend validator.

Fields

source_txid: [u8; 32]

The transaction ID of the source UTXO (32 bytes, internal byte order).

source_output_index: u32

The index of the output in the source transaction.

source_satoshis: u64

The satoshi value of the source UTXO.

locking_script: LockingScript

The locking script of the source UTXO.

transaction_version: i32

The version of the spending transaction.

other_inputs: Vec<TxInput>

Other inputs in the spending transaction (excluding this one).

outputs: Vec<TxOutput>

Outputs of the spending transaction.

input_index: usize

The index of this input in the spending transaction.

unlocking_script: UnlockingScript

The unlocking script for this spend.

input_sequence: u32

The sequence number of this input.

lock_time: u32

The lock time of the spending transaction.

memory_limit: Option<usize>

Optional memory limit in bytes (default: 32MB).