pub enum SignOutputs {
All,
None,
Single,
}Expand description
Specifies which outputs to sign in a transaction signature.
Variants
All
Sign all outputs (SIGHASH_ALL).
None
Sign no outputs (SIGHASH_NONE).
Single
Sign only the output at the same index as the input (SIGHASH_SINGLE).
Implementations
Sourceimpl SignOutputs
impl SignOutputs
Sourcepub fn to_sighash_flag(self) -> u32
pub fn to_sighash_flag(self) -> u32
Converts to the sighash flag value.