build_p2pkh_unlocking_script

Function build_p2pkh_unlocking_script 

pub fn build_p2pkh_unlocking_script(
    tx_sig: &TransactionSignature,
    private_key: &PrivateKey,
) -> UnlockingScript
Helper function to build an unlocking script from signature and public key.

Creates an unlocking script with the signature in checksig format followed by the compressed public key.