Script chunk representation.
A ScriptChunk represents a single element of a script: either an opcode or a data push operation.
Structs
- Script
Chunk - A representation of a chunk of a script, which includes an opcode. For push operations, the associated data to push onto the stack is also included.