UnlockingScript

Struct UnlockingScript 

pub struct UnlockingScript(/* private fields */);
Represents an unlocking script (input script / scriptSig).

An unlocking script provides the data needed to satisfy a locking script’s conditions in order to spend the output.

Implementations

Source

impl UnlockingScript

pub fn new() -> Self

Creates a new empty unlocking script.

pub fn from_chunks(chunks: Vec<ScriptChunk>) -> Self

Creates an unlocking script from a vector of chunks.

pub fn from_asm(asm: &str) -> Result<Self>

Constructs an UnlockingScript from an ASM formatted string.

pub fn from_hex(hex: &str) -> Result<Self>

Constructs an UnlockingScript from a hexadecimal string.

pub fn from_binary(bin: &[u8]) -> Result<Self>

Constructs an UnlockingScript from binary data.

pub fn from_script(script: Script) -> Self

Constructs an UnlockingScript from a Script.

pub fn as_script(&self) -> &Script

Returns a reference to the underlying Script.

pub fn into_script(self) -> Script

Converts this UnlockingScript into its underlying Script.

pub fn to_asm(&self) -> String

Serializes to ASM string.

pub fn to_hex(&self) -> String

Serializes to hex string.

pub fn to_binary(&self) -> Vec<u8>

Serializes to binary.

pub fn chunks(&self) -> Vec<ScriptChunk>

Returns the chunks.

pub fn len(&self) -> usize

Returns the number of chunks.

pub fn is_empty(&self) -> bool

Returns true if empty.

pub fn is_push_only(&self) -> bool

Checks if push-only.

pub fn is_locking_script(&self) -> bool

Returns false (this is not a locking script).

pub fn is_unlocking_script(&self) -> bool

Returns true (this is an unlocking script).